@@ -151,6 +151,10 @@ void Kwave::FileInfo::PropertyTypesMap::fill()
         _(kli18n("Genre").untranslatedText()),
         kli18n("Describes the genre or style of the original work.\n"
             "Examples: 'classic', 'pop'"));
+    append(Kwave::INF_ID3,
+           FP_INTERNAL | FP_NO_LOAD_SAVE,
+           _(kli18n("ID3 Tags").untranslatedText()),
+           kli18n("List of ID3 Tags"));
     append(Kwave::INF_ISRC,
         FP_READONLY,
         _(kli18n("ISRC").untranslatedText()),
@@ -456,6 +460,15 @@ void Kwave::FileInfo::setTracks(unsigned int tracks)
     set(Kwave::INF_CHANNELS, tracks);
 }
 
+//***************************************************************************
+static inline QString shortened(const QString &str)
+{
+    if (str.length() < 1024)
+        return _("'") + str + _("'");
+    else
+        return _("'") + str.left(1024) + _("'...");
+}
+
 /***************************************************************************/
 void Kwave::FileInfo::dump() const
 {
@@ -474,12 +487,26 @@ void Kwave::FileInfo::dump() const
 //     }
 
     qDebug("other properties:");
-    QMap<Kwave::FileProperty, QVariant>::Iterator it;
     foreach (Kwave::FileProperty key, m_property_map.keys()) {
         if (!contains(key)) continue;
-        QVariant val = get(key);
-        QString name = m_property_map.name(key);
-        qDebug("   '%s' = '%s'", DBG(name), DBG(val.toString()));
+        QString     name = m_property_map.name(key);
+        QVariant    val  = get(key);
+        QStringList list = val.toStringList();
+        if (list.size() > 1)
+        {
+            int index = 0;
+            foreach (const QString &s, list)
+            {
+                if (index > 32) {
+                    qDebug("    ..."); // emergency break
+                    break;
+                }
+                qDebug("   '%s[%2d]' = %s", DBG(name), index++,
+                       DBG(shortened(s)));
+            }
+        }
+        else
+            qDebug("   '%s' = %s", DBG(name), DBG(shortened(val.toString())));
 
 //      for updating the list of properties in the appendix of the handbook:
 //      QString name  = m_property_map.name(key);
