@@ -54,7 +54,7 @@ namespace Kwave
         RecordPulseAudio();
 
         /** Destructor */
-        virtual ~RecordPulseAudio() Q_DECL_OVERRIDE;
+        ~RecordPulseAudio() override;
 
         /**
          * Open the record device.
@@ -65,13 +65,13 @@ namespace Kwave
          * @retval QString(...) device specific error message
          *                      (already translated)
          */
-        virtual QString open(const QString& dev) Q_DECL_OVERRIDE;
+        QString open(const QString& dev) override;
 
         /** Returns the current endianness (big/little) */
-        virtual Kwave::byte_order_t endianness() Q_DECL_OVERRIDE;
+        Kwave::byte_order_t endianness() override;
 
         /** Returns the current sample format (signed/unsigned) */
-        virtual Kwave::SampleFormat::Format sampleFormat() Q_DECL_OVERRIDE;
+        Kwave::SampleFormat::Format sampleFormat() override;
 
         /**
          * Try to set a new sample format (signed/unsigned)
@@ -80,37 +80,37 @@ namespace Kwave
          * @see class SampleFormat
          */
         virtual int setSampleFormat(Kwave::SampleFormat::Format new_format)
-            Q_DECL_OVERRIDE;
+            override;
 
         /**
          * Gets a list of supported sample formats.
          * @note this depends on the current setting of the compression!
          */
         virtual QList<Kwave::SampleFormat::Format> detectSampleFormats()
-            Q_DECL_OVERRIDE;
+            override;
 
         /**
          * Returns the current resolution in bits per sample or a negative
          * error code if failed
          */
-        virtual int bitsPerSample() Q_DECL_OVERRIDE;
+        int bitsPerSample() override;
 
         /**
          * Set the resolution in bits per sample
          * @param new_bits resolution [bits/sample]
          * @return zero on success, negative error code if failed
          */
-        virtual int setBitsPerSample(unsigned int new_bits) Q_DECL_OVERRIDE;
+        int setBitsPerSample(unsigned int new_bits) override;
 
         /**
          * Detect a list of supported bits per sample.
          * @note this depends on the compression type
          * @return a list of bits per sample, empty if failed
          */
-        virtual QList< unsigned int > supportedBits() Q_DECL_OVERRIDE;
+        QList< unsigned int > supportedBits() override;
 
         /** Returns the current compression type (0==none) */
-        virtual Kwave::Compression::Type compression() Q_DECL_OVERRIDE;
+        Kwave::Compression::Type compression() override;
 
         /**
          * Try to set a new compression type.
@@ -119,17 +119,17 @@ namespace Kwave
          * @see class Compression
          */
         virtual int setCompression(Kwave::Compression::Type new_compression)
-            Q_DECL_OVERRIDE;
+            override;
 
         /**
          * Gets a list of supported compression types. If no compression is
          * supported, the list might be empty.
          */
         virtual QList<Kwave::Compression::Type> detectCompressions()
-            Q_DECL_OVERRIDE;
+            override;
 
         /** Returns the current sample rate of the device */
-        virtual double sampleRate() Q_DECL_OVERRIDE;
+        double sampleRate() override;
 
         /**
          * Try to set a new sample rate.
@@ -138,13 +138,13 @@ namespace Kwave
          *        sample rate if the underlying driver supports that.
          * @return zero on success, negative error code if failed
          */
-        virtual int setSampleRate(double& new_rate) Q_DECL_OVERRIDE;
+        int setSampleRate(double& new_rate) override;
 
         /** get a list of supported sample rates */
-        virtual QList< double > detectSampleRates() Q_DECL_OVERRIDE;
+        QList< double > detectSampleRates() override;
 
         /** Returns the current number of tracks */
-        virtual int tracks() Q_DECL_OVERRIDE;
+        int tracks() override;
 
         /**
          * Try to set a new number of tracks.
@@ -154,7 +154,7 @@ namespace Kwave
          *        underlying driver supports that.
          * @return zero on success, negative error code if failed
          */
-        virtual int setTracks(unsigned int& tracks) Q_DECL_OVERRIDE;
+        int setTracks(unsigned int& tracks) override;
 
         /**
          * Detect the minimum and maximum number of tracks.
@@ -165,10 +165,10 @@ namespace Kwave
          *         negative error number if failed
          */
         virtual int detectTracks(unsigned int& min, unsigned int& max)
-            Q_DECL_OVERRIDE;
+            override;
 
         /** Close the device */
-        virtual int close() Q_DECL_OVERRIDE;
+        int close() override;
 
         /**
          * Read the raw audio data from the record device.
@@ -178,10 +178,10 @@ namespace Kwave
          * @return number of bytes read, zero or negative if failed
          */
         virtual int read(QByteArray& buffer, unsigned int offset)
-            Q_DECL_OVERRIDE;
+            override;
 
         /** return a string list with supported device names */
-        virtual QStringList supportedDevices() Q_DECL_OVERRIDE;
+        QStringList supportedDevices() override;
 
         /**
          * our own poll function, for timeout support
@@ -193,7 +193,7 @@ namespace Kwave
     protected:
 
         /** re-implementation of the threaded mainloop of PulseAudio */
-        virtual void run_wrapper(const QVariant &params) Q_DECL_OVERRIDE;
+        void run_wrapper(const QVariant &params) override;
 
     private:
 
