@@ -25,10 +25,11 @@
 
 #include "libkwave/Plugin.h"
 #include "libkwave/Sample.h"
-#include "libkwave/SampleArray.h"
 
 namespace Kwave
 {
+    class SampleArray;
+
     /**
      * @class ReversePlugin
      * Reverses the current selection by exchanging blocks of samples
@@ -48,13 +49,13 @@ namespace Kwave
         ReversePlugin(QObject *parent, const QVariantList &args);
 
         /** Destructor */
-        virtual ~ReversePlugin() Q_DECL_OVERRIDE;
+        ~ReversePlugin() override;
 
         /**
          * reverses the selection
          * @param params list of strings with parameters
          */
-        virtual void run(QStringList params) Q_DECL_OVERRIDE;
+        void run(QStringList params) override;
 
     private slots:
 
@@ -62,7 +63,7 @@ namespace Kwave
          * multiplies the progress by factor two and
          * calls Kwave::Plugin::updateProgress
          */
-        virtual void updateProgress(qreal progress) Q_DECL_OVERRIDE;
+        void updateProgress(qreal progress) override;
 
     private:
 
